#
# spec file for package telepathy-qt5
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         libname libtelepathy-qt5
%define         major   0

# SLE12 does not have farstream support in ppc64le but openSUSE Factory and Ports does
%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
%ifnarch ppc64le
%define with_farstream 1
%endif
%else
%define with_farstream 1
%endif

Name:           telepathy-qt5
Version:        0.9.6.1
Release:        2.3
Summary:        Qt4 bindings for the Telepathy Library
License:        LGPL-2.1+
Group:          Development/Tools/Other
Url:            http://telepathy.freedesktop.org/
Source:         http://telepathy.freedesktop.org/releases/telepathy-qt/telepathy-qt-%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM telepathy-qt5-gst-1_6.patch zaitor@opensuse.org -- Fix build with gstreamer 1.6 and newer.
Patch0:         telepathy-qt5-gst-1_6.patch
BuildRequires:  cmake
BuildRequires:  dbus-1-python
BuildRequires:  fdupes
# FIXME patch, or make upstream look for qhelpgenerator-qt5 first
#BuildRequires:  libqt5-qttools-devel
#BuildRequires:  doxygen
BuildRequires:  libxml2-devel
BuildRequires:  python-xml
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
%if 0%{?with_farstream}
BuildRequires:  pkgconfig(farstream-0.2)
BuildRequires:  pkgconfig(telepathy-farstream)
%endif
BuildRequires:  pkgconfig(telepathy-glib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Telepathy-Qt5 is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 5.

%package -n %{libname}-%{major}
Summary:        Library for performing syntax highlighting in Qt documents
Group:          Development/Tools/Other

%description -n %{libname}-%{major}
Telepathy-Qt5 is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 5.

%if 0%{?with_farstream}
%package -n %{libname}-farstream%{major}
Summary:        Library for performing syntax highlighting in Qt documents
Group:          Development/Tools/Other

%description -n %{libname}-farstream%{major}
Telepathy-farstream-Qt4 is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 5.
%endif

%package devel
Summary:        Header files, libraries and development documentation for %{name}
Group:          Development/Libraries/C and C++
Provides:       %{name}-service-devel-static = %{version}
Requires:       %{libname}-%{major} = %{version}
%if 0%{?with_farstream}
Requires:       %{libname}-farstream%{major} = %{version}
%endif
Requires:       pkgconfig(gstreamer-1.0)
Requires:       pkgconfig(gstreamer-plugins-base-1.0)

%description devel
This package contains the header files, static libraries and development documentation for %{name}. If you like to develop programs using %{name}, you will need to install %{name}-devel.

%prep
%setup -q -n telepathy-qt-%{version}
%patch0 -p1

%build
if [ %{_lib} = lib64 ]; then
  EXTRA_FLAGS="$EXTRA_FLAGS -DLIB_SUFFIX=64"
fi
mkdir build
cd build
cmake -DCMAKE_BUILD_TYPE=release \
      -DCMAKE_INSTALL_PREFIX=/usr \
      -DCMAKE_C_FLAGS="%{optflags}" \
      -DCMAKE_CXX_FLAGS="%{optflags}" \
      -DENABLE_TESTS=FALSE \
      -DENABLE_EXAMPLES=FALSE \
      -DENABLE_FARSIGHT=FALSE \
%if 0%{?with_farstream}
      -DENABLE_FARSTREAM=TRUE \
%endif
      -DDISABLE_WERROR=TRUE \
      -DDESIRED_QT_VERSION=5 $EXTRA_FLAGS ..

make %{?_smp_mflags}

%install
%makeinstall -C build
%fdupes %{buildroot}

%post -n %{libname}-%{major} -p /sbin/ldconfig

%postun -n %{libname}-%{major} -p /sbin/ldconfig

%if 0%{?with_farstream}
%post -n %{libname}-farstream%{major} -p /sbin/ldconfig

%postun -n %{libname}-farstream%{major} -p /sbin/ldconfig
%endif

%files -n %{libname}-%{major}
%defattr(-,root,root)
%{_libdir}/libtelepathy-qt5.so.*

%if 0%{?with_farstream}
%files -n %{libname}-farstream%{major}
%defattr(-,root,root)
%{_libdir}/libtelepathy-qt5-farstream.so.*
%endif

%files devel
%defattr(-,root,root)
%doc AUTHORS ChangeLog README COPYING HACKING NEWS
%{_includedir}/telepathy-qt5/
%{_libdir}/libtelepathy-qt5*.so
%{_libdir}/libtelepathy-qt5-service.a
%{_libdir}/pkgconfig/TelepathyQt5*.pc
%{_libdir}/cmake/TelepathyQt5*/

%changelog
* Mon Jan 11 2016 mlin@suse.com
- Do not require libtelepathy-qt5-farstream if it does not build
* Sun Jan 10 2016 mlin@suse.com
- Partial revert the last commit, do not disable the farstream subpackage
  for ppc64le on all version, just disabled it on SLE12.
* Tue Dec 22 2015 alarrosa@suse.com
- Disable the farstream subpackage for ppc64le, since SLE12 doesn't have
  farstream packages in that architecture
* Sun Nov 29 2015 zaitor@opensuse.org
- Update to version 0.9.6.1:
  + Fixed illegal C++ statement in one of service interfaces.
- Add telepathy-qt5-gst-1_6.patch: Fix build with gstreamer-1.6.
* Tue May 19 2015 hrvoje.senjan@gmail.com
- Update to 0.9.6:
  - Enhancements:
  * Added TP_QT_VERSION and TP_QT_VERSION_CHECK macros
  - Can be used like #if (TP_QT_VERSION == TP_QT_VERSION_CHECK(0, 9, 6))
  - Absence of the TP_QT_VERSION macros indicates previous versions
    (might be useful for service bindings compatibility)
  * Added client side support for conference calls
  * Implemented numerous interfaces for service bindings
  - API changes:
  * Refactored service-side bindings API
  - BaseConnection createChannel() and ensureChannel() methods
    now accept request map instead of several extracted values.
  - BaseChannel::create() arguments reordered in natural way.
  - Fixes:
  * Fixed CallContent interfaces exposing (required for DTMF)
  * fd0#86312: Fixed condition in adaptor methods generation
- Drop patches merged upstream:
  Add-missing-QObject-include.patch and add-the-telepathy-qt-include.patch
* Sun Mar 29 2015 hrvoje.senjan@gmail.com
- Add-missing-QObject-include.patch: fixed build with Qt 5.5
* Mon Dec 15 2014 hrvoje.senjan@gmail.com
- Added add-the-telepathy-qt-include.patch
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 0.9.5:
  * Added more service side bindings
  * Service bindings now enabled by default
  * Bump Farstream version
  * Allow subclass of Tp::ReceivedMessage
  * Workaround invalid channelRequests when delegating, fdo#77986
- Drop search-for-gstreamer1.0.diff and search-for-farstream0.2.diff,
  merged upstream
- Provide telepathy-qt5-service-devel-static, due to newly enabled
  service library
* Thu Jul 31 2014 hrvoje.senjan@gmail.com
- Move to gstreamer 1.0 API for Factory
- Drop search-for-telepathy-farstream-0.4.diff (support for older
  openSUSE versions is dropped)
- Adjust baselibs.conf for new subpackage
- Update descriptions
* Mon Jun 16 2014 hrvoje.senjan@gmail.com
- Update to 0.9.4
  + Enhancements:
  * fdo#63098: add method Account::createDbusTubeRoom
  + Fixes:
  * fdo#46241: Fixed linking in farstream and farsight
  * Require tp-glib 0.18 and fix 0.19-ism
  * fdo#47647: Fixed storing avatars, so that they are not stored
    millions of times each.
  * fdo#62711: Fixed stack overflow in SimpleObserver::create
  * Fix compilation and running against release Qt5
- Drop patches included in this release:
    0012-Fix-warning-in-DBusTubeChannel.patch
    0035-Fix-ChannelDispatcher.Messages-test.patch
    0031-Update-to-spec-0.27.3.patch
    0026-Fix-tests-build-for-Qt5-release.patch
    0021-account-add-method-Account-createDbusTubeRoom.patch
    0036-Fix-moc-command-for-Qt5.2.patch
    0030-Fix-HandledChannelNotifier-for-Qt5.patch
    0007-Link-telepathy-qt4-farsight-against-gobject.patch
    0005-Start-0.9.4-development.patch
    0039-Add-Q_UNUSED-as-Q_ASSERT-is-a-no-op-in-release-mode.patch
    0025-Fix-build-for-Qt5-release.patch
    0010-cmake-Require-tp-glib-0.18.patch
    0006-farsight-Fix-linking.patch
    0029-Fix-TestDBusProxyFactory-testDropRefs.patch
    0009-glib-Disable-tp_tests_connection_run_until_contact_b.patch
    0028-Fix-TestAccountSet-testFilters.patch
    0038-Allow-compilation-when-only-qmake-qt4-is-in-the-path.patch
    0023-Kill-the-last-bits-of-Farsight.patch
    0027-Fix-TestKeyFile-sort-list-before-comparing.patch
    0018-tests-sync-simple-channel-dispatch-operation.c-from-.patch
    0040-Add-5-to-pkg-config-package-names-for-Qt5.patch
    0037-Simplify-FindQt5.cmake.patch
    0032-Update-changes-from-Channel_Dispatcher_Future.patch
    0034-Add-Room-Subject-RoomConfig-interfaces-to-generation.patch
    0015-Fix-stack-overflow-in-SimpleObserver-create.patch
    0024-Fix-compilation-on-new-versions-of-cmake.patch
    0017-Remove-references-to-deprecated-tp_channel_borrow_im.patch
    0013-Fix-storing-avatars-so-that-they-are-not-stored-mill.patch
    0019-Removing-old-Farsight-files.patch
    0033-Update-test-library-to-match-spec-changes.patch
- Simplify cmake usage during %%build phase
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
* Sun Apr 13 2014 hrvoje.senjan@gmail.com
- Activate telepathy-qt5 package
